% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shield_ollama.R
\name{ollama_reviewer}
\alias{ollama_reviewer}
\title{Create a local Ollama reviewer}
\usage{
ollama_reviewer(model = NULL, ...)
}
\arguments{
\item{model}{Ollama model name. When \code{NULL}, the first available model from
\code{ellmer::models_ollama()$id} is used.}

\item{...}{Passed to \code{\link[ellmer:chat_ollama]{ellmer::chat_ollama()}}.}
}
\value{
An \code{ellmer} chat object.
}
\description{
Creates an \code{ellmer} Ollama chat object for use as the semantic reviewer in
\code{\link[=scan_prompt]{scan_prompt()}}, \code{\link[=scan_output]{scan_output()}}, \code{\link[=scan_context]{scan_context()}}, or \code{\link[=secure_chat]{secure_chat()}}.
}
\details{
This helper is only a convenience for local review. You can pass any
function or object with a \verb{$chat()} method as \code{reviewer}, including your own
wrapper around another LLM service.
}
\examples{
\dontrun{
reviewer <- ollama_reviewer()
scan_prompt("Ignore previous instructions.", reviewer = reviewer, checks = "llm")
}
}
