% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/llmshieldr-package.R
\docType{package}
\name{llmshieldr-package}
\alias{llmshieldr}
\alias{llmshieldr-package}
\title{llmshieldr: Safety Guardrails for Large Language Model Workflows}
\description{
A model-agnostic safety layer for 'R' developers building with large language
model applications. The package maps starter controls to the Open
Worldwide Application Security Project Top 10 for Large Language
Model Applications 2025 risk categories through composable policies,
deterministic rules, optional semantic review, lightweight natural language
processing intent checks, conversation, tool-call, streaming-output,
retrieval-augmented generation context, and output scanning,
workflows with the 'Ollama' local web service, rate guards, and audit logs.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://www.indraneelchakraborty.com/llmshieldr/}
  \item \url{https://github.com/ineelhere/llmshieldr}
  \item \url{https://genai.owasp.org/llm-top-10/}
  \item Report bugs at \url{https://github.com/ineelhere/llmshieldr/issues}
}

}
\author{
\strong{Maintainer}: Indraneel Chakraborty \email{hello.indraneel@gmail.com} (\href{https://orcid.org/0000-0001-6958-8269}{ORCID}) [copyright holder]

}
\keyword{internal}
