% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/policy.R
\name{remove_rule}
\alias{remove_rule}
\title{Remove a rule from a policy}
\usage{
remove_rule(policy, id)
}
\arguments{
\item{policy}{A \code{shieldr_policy} or built-in policy name such as \code{"comprehensive"}.}

\item{id}{Rule identifier to remove.}
}
\value{
The modified \code{shieldr_policy}, invisibly.
}
\description{
Remove a rule from a policy
}
\examples{
policy <- build_policy(rules = list(rule_pii_email()))
policy <- remove_rule(policy, "llm02.pii.email")
}
